@@ -10,7 +10,7 @@ module Yesod.Auth.OAuth
     , tumblrUrl
     , module Web.Authenticate.OAuth
     ) where
-import           Control.Applicative      ((<$>), (<*>))
+import           Control.Applicative      as A ((<$>), (<*>))
 import           Control.Arrow            ((***))
 import           Control.Exception.Lifted
 import           Control.Monad.IO.Class
@@ -66,8 +66,8 @@ authOAuth oauth mkCreds = AuthPlugin name dispatch login
                                 ]
           else do
             (verifier, oaTok) <-
-                runInputGet $ (,) <$> ireq textField "oauth_verifier"
-                                  <*> ireq textField "oauth_token"
+                runInputGet $ (,) A.<$> ireq textField "oauth_verifier"
+                                  A.<*> ireq textField "oauth_token"
             return $ Credential [ ("oauth_verifier", encodeUtf8 verifier)
                                 , ("oauth_token", encodeUtf8 oaTok)
                                 , ("oauth_token_secret", encodeUtf8 tokSec)
@@ -83,7 +83,7 @@ authOAuth oauth mkCreds = AuthPlugin name dispatch login
         let oaUrl = render $ tm $ oauthUrl name
         [whamlet| <a href=#{oaUrl}>Login via #{name} |]
 
-mkExtractCreds :: YesodAuth m => Text -> String -> Credential -> IO (Creds m)
+mkExtractCreds :: Text -> String -> Credential -> IO (Creds m)
 mkExtractCreds name idName (Credential dic) = do
   let mcrId = decodeUtf8With lenientDecode <$> lookup (encodeUtf8 $ T.pack idName) dic
   case mcrId of
